.. Segway documentation master file, created by
   sphinx-quickstart on Thu Apr 16 15:13:23 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Segway's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2

   segway

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

